﻿(function () {
    'use strict';

    angular
        .module('app', [
            'ngRoute', 
            'ngCookies', 
            'angularTreeview',
            'ui.bootstrap', 
            'ngResource', 
            'ngSanitize', 
            'ngFormBuilder', 
            'formio', 
            'ngJsonExplorer', 
            'ui.select', 
            'treeControl',
            'mgo-angular-wizard', 
            'appmarkers', 
            'directive.g+signin'
        ])
        .config(config)
        .run(run);


    config.$inject = ['$routeProvider', '$locationProvider', '$httpProvider','$resourceProvider', '$compileProvider'];
    function config($routeProvider, $locationProvider, $httpProvider,$resourceProvider, $compileProvider) {
        $compileProvider.preAssignBindingsEnabled(true);

        $httpProvider.defaults.useXDomain = true;

        $routeProvider
            .when('/dashboard', {
                controller: 'HomeController',
                templateUrl: 'modules/home/home.view.html',
                controllerAs: 'vm'
            })
            .when('/login', {
                controller: 'LoginController',
                templateUrl: 'modules/login/login.view.html',
                controllerAs: 'vm',
            })
            .when('/register', {
                controller: 'RegisterController',
                templateUrl: 'modules/register/register.view.html',
                controllerAs: 'vm'
            })
            .when('/releveplus', {
                controller: 'ReleveplusController',
                templateUrl: 'modules/releveplus/releveplus.view.html',
                controllerAs: 'vm'
            })
            .when('/releveplus/formbuilder/create', {
                controller: 'formbuilderController',
                templateUrl: 'modules/releveplus/formbuilder/create/form.builder.view.html',
                controllerAs: 'vm',
                resolve: {}
            })
            .when('/releveplus/formbuilder', {
                controller: 'RPListFormsController',
                templateUrl: 'modules/releveplus/formbuilder/list/form.builder.list.view.html',
                controllerAs: 'vm',
                resolve: {}
            })
            .otherwise({ redirectTo: '/login' });
        $locationProvider.html5Mode(false);
    }

    run.$inject = ['$rootScope', '$location', '$cookies', '$http', '$route'];
    function run($rootScope, $location, $cookies, $http, $routeParams,          formioComponents,
                 $timeout) {

        $rootScope.loading_data = false;
        $rootScope.flashModal = false;
        $rootScope.flashModalDelete = function () {
            delete $rootScope.flashModal;
        };

        // current route class
        $rootScope.routeClassName = 'default';
        $rootScope.$on('$routeChangeSuccess', function(e, current, pre) {
            $rootScope.routeClassName = $location.path().replace('/','');;
        });
        //
        $rootScope.isActive = function(viewLocation) {
            return viewLocation === $location.path();
        };

        // keep user logged in after page refresh
        $rootScope.globals = $cookies.getObject('globals') || {};
        if ($rootScope.globals.currentUser) {
            $http.defaults.headers.common['Authorization'] = 'Basic ' + $rootScope.globals.currentUser.authdata;
        }

        $rootScope.$on('$locationChangeStart', function (event, next, current) {
            // redirect to login page if not logged in and trying to access a restricted page

            var restrictedPage = $.inArray($location.path(), ['/login', '/register']) === -1;
            var loggedIn = $rootScope.globals.currentUser;
            if (restrictedPage && !loggedIn) {
                $location.path('/login');
            }

        });

    }})();
