﻿(function () {
    'use strict';

    // Main module 'app' creation, + imports
    angular
        .module('app', [
            
            'angularTreeview',
            
            'app.board',
            'app.navigation',
            
            'appmarkers',
            'directive.g+signin',
            'formio',
            'mgo-angular-wizard',
            
            'ngCookies',
            'ngFormBuilder',
            'ngJsonExplorer',
            'ngMap',
            'ngResource',
            'ngRoute',
            'ngSanitize',
            
            'open-vts',
            'treeControl',
            
            'ui.bootstrap',
            'ui.select'

        ])
        .config(config)
        .run(run);


    // Configuration functions, dependency injections
    config.$inject = [  '$compileProvider',     '$httpProvider',    '$locationProvider',    '$resourceProvider',    '$routeProvider'    ];
    function config(    $compileProvider,       $httpProvider,      $locationProvider,      $resourceProvider,      $routeProvider      ) {
        
        $compileProvider.preAssignBindingsEnabled(true);
        $httpProvider.defaults.useXDomain = true;

        $routeProvider
            .when('/dashboard', {
                controller:     'HomeController',
                controllerAs:   'vm',
                templateUrl:    'modules/home/home.view.html',
            })

            .when('/login', {
                controller:     'LoginController',
                controllerAs:   'vm',
                templateUrl:    'modules/login/login.view.html'
            })

            .when('/register', {
                controller:     'RegisterController',
                controllerAs:   'vm',
                templateUrl:    'modules/register/register.view.html'
            })

            .when('/releveplus', {
                controller:     'ReleveplusController',
                controllerAs:   'vm',
                templateUrl:    'modules/releveplus/releveplus.view.html'
            })

            .when('/releveplus/formbuilder/create', {
                controller:     'formbuilderController',
                controllerAs:   'vm',
                resolve: {

                },
                templateUrl:    'modules/releveplus/formbuilder/create/form.builder.view.html'
            })

            .when('/releveplus/formbuilder', {
                controller:     'RPListFormsController',
                templateUrl:    'modules/releveplus/formbuilder/list/form.builder.list.view.html',
                resolve: {

                },
                controllerAs:   'vm'
            })



            // Tests max
            .when('/pageVierge', {
                controller:     'PageViergeController',
                templateUrl:    'modules/max/pageVierge/pageVierge.view.html',
                controllerAs:   'vm',
                resolve: {

                }
            })

            .when('/max-toolbox', { // ne pas appeler toolbox tout court, sinon conflit de classes (ajout auto par angular dans le container parent)
                controller:     'ToolboxController',
                templateUrl:    'modules/max/toolbox/toolbox.view.html',
                controllerAs:   'vm',
                resolve: {

                }
            })


            .otherwise({
                redirectTo: '/login'
            })
        ;
        
        $locationProvider.html5Mode(false);
    }



    // Run functions
    run.$inject = [ '$cookies', '$http',    '$location',    '$rootScope',   '$route'    ];
    function run(   $cookies,   $http,      $location,      $rootScope,     $routeParams,   formioComponents,   $timeout) {

        // inits
        $rootScope.loading_data = false;
        $rootScope.flashModal = false;
        $rootScope.flashModalDelete = function () {
            delete $rootScope.flashModal;
        };

        // current route class
        $rootScope.routeClassName = 'default';
        $rootScope.$on('$routeChangeSuccess', function(e, current, pre) {
            $rootScope.routeClassName = $location.path().replace('/','');;
        });
        
        //
        $rootScope.isActive = function(viewLocation) {
            return viewLocation === $location.path();
        };

        // keep user logged in after page refresh
        $rootScope.globals = $cookies.getObject('globals') || {};
        if ($rootScope.globals.currentUser) {
            $http.defaults.headers.common['Authorization'] = 'Basic ' + $rootScope.globals.currentUser.authdata;
        }

        $rootScope.$on('$locationChangeStart', function (event, next, current) {
            // redirect to login page if not logged in and trying to access a restricted page

            var restrictedPage = $.inArray($location.path(), ['/login', '/register']) === -1;
            var loggedIn = $rootScope.globals.currentUser;
            if (restrictedPage && !loggedIn) {
                $location.path('/login');
            }

        });

    }

})();
